BottomPicker<T>.time constructor

BottomPicker<T>.time({
  1. Key? key,
  2. required Time? initialTime,
  3. Time? maxTime,
  4. Time? minTime,
  5. bool dismissable = false,
  6. dynamic onChange(
    1. T
    )?,
  7. @Deprecated('Use buttonBuilder with a callback widget to handle the onSubmit action instead') dynamic onSubmit(
    1. T?
    )?,
  8. @Deprecated('Use buttonBuilder with a callback widget to handle the onSubmit action instead') bool? closeOnSubmit = true,
  9. dynamic onDismiss(
    1. T?
    )?,
  10. BottomPickerTheme bottomPickerTheme = BottomPickerTheme.blue,
  11. List<Color>? gradientColors,
  12. int minuteInterval = 1,
  13. bool use24hFormat = false,
  14. Color backgroundColor = Colors.white,
  15. CupertinoTextThemeData? pickerThemeData,
  16. TextDirection? layoutOrientation = TextDirection.ltr,
  17. double? height,
  18. bool showTimeSeparator = false,
  19. double itemExtent = 30,
  20. Widget headerBuilder(
    1. BuildContext context
    )?,
  21. List<int> calendarDays = CupertinoDatePickerWidget.fullWeek,
  22. double diameterRatio = 1.1,
  23. bool useSafeArea = false,
  24. Widget buttonBuilder(
    1. BottomPicker instance,
    2. BuildContext context
    )?,
  25. @Deprecated('Use buttonBuilder instead') bool displaySubmitButton = true,
  26. @Deprecated('Use buttonBuilder instead') Widget? buttonContent,
  27. @Deprecated('Use buttonBuilder instead') BoxDecoration? buttonStyle,
  28. @Deprecated('Use buttonBuilder instead') MainAxisAlignment buttonAlignment = MainAxisAlignment.center,
  29. @Deprecated('Use buttonBuilder instead') Color? buttonSingleColor,
  30. @Deprecated('Use buttonBuilder instead') double? buttonPadding,
  31. @Deprecated('Use buttonBuilder instead') double? buttonWidth,
  32. TextStyle? pickerTextStyle,
})

Implementation

BottomPicker.time({
  super.key,
  required this.initialTime,
  this.maxTime,
  this.minTime,
  this.dismissable = false,
  this.onChange,
  @Deprecated(
    'Use buttonBuilder with a callback widget to handle the onSubmit action instead',
  )
  this.onSubmit,
  @Deprecated(
    'Use buttonBuilder with a callback widget to handle the onSubmit action instead',
  )
  this.closeOnSubmit = true,
  this.onDismiss,
  this.bottomPickerTheme = BottomPickerTheme.blue,
  this.gradientColors,
  this.minuteInterval = 1,
  this.use24hFormat = false,
  this.backgroundColor = Colors.white,
  this.pickerThemeData,
  this.layoutOrientation = TextDirection.ltr,
  this.height,
  this.showTimeSeparator = false,
  this.itemExtent = 30,
  this.headerBuilder,
  this.calendarDays = CupertinoDatePickerWidget.fullWeek,
  this.diameterRatio = 1.1,
  this.useSafeArea = false,
  this.buttonBuilder,
  @Deprecated('Use buttonBuilder instead') this.displaySubmitButton = true,
  @Deprecated('Use buttonBuilder instead') this.buttonContent,
  @Deprecated('Use buttonBuilder instead') this.buttonStyle,
  @Deprecated('Use buttonBuilder instead')
  this.buttonAlignment = MainAxisAlignment.center,
  @Deprecated('Use buttonBuilder instead') this.buttonSingleColor,
  @Deprecated('Use buttonBuilder instead') this.buttonPadding,
  @Deprecated('Use buttonBuilder instead') this.buttonWidth,
  this.pickerTextStyle,
}) {
  datePickerMode = CupertinoDatePickerMode.time;
  bottomPickerType = BottomPickerType.time;
  dateOrder = null;
  onRangeDateSubmitPressed = null;
  initialDateTime = null;
  assertInitialValues();
}