buttonPadding property

  1. @Deprecated('Use buttonBuilder instead')
double? buttonPadding
final

the padding that will be applied to the button if the padding is null the button will be rendered null

Implementation

@Deprecated('Use buttonBuilder instead')
final double? buttonPadding;