buttonWidth property

  1. @Deprecated('Use buttonBuilder instead')
double? buttonWidth
final

the width that will be applied to the button if the buttonWidth is null the button will be rendered with null

Implementation

@Deprecated('Use buttonBuilder instead')
final double? buttonWidth;