closeOnSubmit property
Indiacate whether the bottom picker will be closed (poped out of the Navigator) when the submit button is pressed. By default closeOnSubmit = true.
Implementation
bool? closeOnSubmit;
Indiacate whether the bottom picker will be closed (poped out of the Navigator) when the submit button is pressed. By default closeOnSubmit = true.
bool? closeOnSubmit;