onSubmit property
dynamic Function(T?)?
onSubmit
getter/setter pair
Nullable function invoked when clicking on submit button if the picker type is date/time/dateTime it will return DateTime value else it will return the index of the selected item
Implementation
late Function(T?)? onSubmit;