BottomPickerButton class

A button widget that can be used to open the bottom picker.

Inheritance
Annotations
  • @Deprecated('Will be replaced with button builder callback in the future. check [BottomPicker].')

Constructors

BottomPickerButton({Key? key, required Function onClick, BottomPickerTheme theme = BottomPickerTheme.blue, List<Color>? gradients, Color? solidColor, double? buttonPadding, double? buttonWidth, Widget? buttonChild, BoxDecoration? style})
const

Properties

buttonChild Widget?
The child widget to be used for the button.
final
buttonPadding double?
The padding to be used for the button.
final
buttonWidth double?
The width of the button.
final
gradients List<Color>?
The list of colors to be used for the gradient background of the button.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClick Function
The callback function that is called when the button is pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solidColor Color?
The solid color to be used for the background of the button.
final
style BoxDecoration?
The style to be used for the button.
final
theme BottomPickerTheme
The theme of the button.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited