DatePicker class

A date picker widget that can be used to select a date or time.

Inheritance

Constructors

DatePicker({Key? key, required DateTime? initialDateTime, int minuteInterval = 1, DateTime? maxDateTime, DateTime? minDateTime, required CupertinoDatePickerMode mode, required dynamic onDateChanged(DateTime), bool use24hFormat = true, required TextStyle? textStyle, DatePickerDateOrder? dateOrder, double? itemExtent = 0, bool showTimeSeparator = false, List<int> calendarDays = CupertinoDatePickerWidget.fullWeek, CupertinoTextThemeData? pickerThemeData, SelectableHourPredicate? hourPredicate})
const

Properties

calendarDays List<int>
The list of days to be displayed in the calendar view of the picker.
final
dateOrder DatePickerDateOrder?
The order in which the date components are displayed in the picker.
final
hashCode int
The hash code for this object.
no setterinherited
hourPredicate SelectableHourPredicate?
The predicate function that determines whether a given hour is selectable in the time picker.
final
initialDateTime DateTime?
The initial date to be displayed in the picker.
final
itemExtent double?
The height of each item in the picker.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxDateTime DateTime?
The maximum date that can be selected in the picker.
final
minDateTime DateTime?
The minimum date that can be selected in the picker.
final
minuteInterval int
The interval of the minutes in the time picker.
final
mode CupertinoDatePickerMode
The mode of the date picker CupertinoDatePickerMode.
final
onDateChanged → dynamic Function(DateTime)
The callback function that is called when the selected date changes.
final
pickerThemeData CupertinoTextThemeData?
The theme data to be used for the picker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTimeSeparator bool
Whether to show the time separator in the time picker.
final
textStyle TextStyle?
The text style to be used for the items in the picker.
final
use24hFormat bool
Whether to use 24-hour format for the time picker.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited