hourPredicate property
The predicate function that determines whether a given hour is selectable in the time picker.
Implementation
final SelectableHourPredicate? hourPredicate;
The predicate function that determines whether a given hour is selectable in the time picker.
final SelectableHourPredicate? hourPredicate;