onDateChanged property
The callback function that is called when the selected date changes.
Implementation
final Function(DateTime) onDateChanged;
The callback function that is called when the selected date changes.
final Function(DateTime) onDateChanged;