pickerThemeData property
CupertinoTextThemeData?
pickerThemeData
final
The theme data to be used for the picker.
Implementation
final CupertinoTextThemeData? pickerThemeData;
The theme data to be used for the picker.
final CupertinoTextThemeData? pickerThemeData;