RangePicker class

A range picker widget that can be used to select a range of dates or times.

Inheritance

Constructors

RangePicker({Key? key, required DateTime? initialFirstDateTime, required DateTime? initialSecondDateTime, required DateTime? maxFirstDate, required DateTime? minFirstDateTime, required DateTime? maxSecondDate, required DateTime? minSecondDateTime, required dynamic onFirstDateChanged(DateTime), required dynamic onSecondDateChanged(DateTime), DatePickerDateOrder? dateOrder, required TextStyle? textStyle, required CupertinoDatePickerMode mode, required bool use24hFormat, int? minuteInterval, double? itemExtent, bool showTimeSeperator = false, CupertinoTextThemeData? pickerThemeData})
const

Properties

dateOrder DatePickerDateOrder?
The order in which the date components are displayed in the picker.
final
hashCode int
The hash code for this object.
no setterinherited
initialFirstDateTime DateTime?
The initial date to be displayed in the first picker.
final
initialSecondDateTime DateTime?
The initial date to be displayed in the second picker.
final
itemExtent double?
The height of each item in the picker.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxFirstDate DateTime?
The maximum date that can be selected in the first picker.
final
maxSecondDate DateTime?
The maximum date that can be selected in the second picker.
final
minFirstDateTime DateTime?
The minimum date that can be selected in the first picker.
final
minSecondDateTime DateTime?
The minimum date that can be selected in the second picker.
final
minuteInterval int?
The interval of the minutes in the time picker.
final
mode CupertinoDatePickerMode
The mode of the date picker CupertinoDatePickerMode.
final
onFirstDateChanged → dynamic Function(DateTime)
The callback function that is called when the first date changes.
final
onSecondDateChanged → dynamic Function(DateTime)
The callback function that is called when the second date changes.
final
pickerThemeData CupertinoTextThemeData?
The theme data to be used for the picker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTimeSeperator bool
Whether to show the time separator in the time picker.
final
textStyle TextStyle?
The text style to be used for the items in the picker.
final
use24hFormat bool
Whether to use 24-hour format for the time picker.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RangePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited