onFirstDateChanged property
The callback function that is called when the first date changes.
Implementation
final Function(DateTime) onFirstDateChanged;
The callback function that is called when the first date changes.
final Function(DateTime) onFirstDateChanged;