onSecondDateChanged property
The callback function that is called when the second date changes.
Implementation
final Function(DateTime) onSecondDateChanged;
The callback function that is called when the second date changes.
final Function(DateTime) onSecondDateChanged;