SimplePicker<T> class

A simple picker widget that can be used to select an item from a list of items.

Inheritance

Constructors

SimplePicker({Key? key, required List<T> items, Widget itemBuilder(T item, int index)?, required dynamic onChange(int)?, required int selectedItemIndex, TextStyle? textStyle, required double itemExtent, Widget? selectionOverlay, CupertinoTextThemeData? pickerThemeData, required double diameterRatio})
const

Properties

diameterRatio double
The diameter ratio of the picker.
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder Widget Function(T item, int index)?
final
itemExtent double
The height of each item in the picker.
final
items List<T>
The list of items to be displayed in the picker.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange → dynamic Function(int)?
The callback function that is called when the selected item changes.
final
pickerThemeData CupertinoTextThemeData?
The theme data to be used for the picker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedItemIndex int
The index of the selected item in the list of items.
final
selectionOverlay Widget?
The widget to be used as the selection overlay in the picker.
final
textStyle TextStyle?
The text style to be used for the items in the picker.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited