initialDuration property
The initial duration to be displayed in the picker. When initialDuration is null, the picker will display a duration of zero.
Implementation
final Duration? initialDuration;
The initial duration to be displayed in the picker. When initialDuration is null, the picker will display a duration of zero.
final Duration? initialDuration;