onChange property

dynamic Function(Duration) onChange
final

The callback function that is called when the selected time changes. a required parameter that cannot be null, and it will be called with the selected time duration.

Implementation

final Function(Duration) onChange;