secondInterval property

int secondInterval
final

The interval of the seconds in the time picker. By default secondInterval is set to 1, which means that the user can select any second value from 0 to 59. if secondInterval is outside the range of 1 to 59 an assertion error will be thrown.

Implementation

final int secondInterval;