onDateChanged property
The callback function that is called when the selected year changes.
Implementation
final Function(DateTime) onDateChanged;
The callback function that is called when the selected year changes.
final Function(DateTime) onDateChanged;