BottomPicker<T>.time constructor
BottomPicker<T>.time ({
- Key? key,
- required Time? initialTime,
- Time? maxTime,
- Time? minTime,
- bool dismissable = false,
- dynamic onChange(
- T
- @Deprecated('Use buttonBuilder with a callback widget to handle the onSubmit action instead') dynamic onSubmit(
- T?
- @Deprecated('Use buttonBuilder with a callback widget to handle the onSubmit action instead') bool? closeOnSubmit = true,
- dynamic onDismiss(
- T?
- BottomPickerTheme bottomPickerTheme = BottomPickerTheme.blue,
- List<
Color> ? gradientColors, - int minuteInterval = 1,
- bool use24hFormat = false,
- Color backgroundColor = Colors.white,
- CupertinoTextThemeData? pickerThemeData,
- TextDirection? layoutOrientation = TextDirection.ltr,
- double? height,
- bool showTimeSeparator = false,
- double itemExtent = 30,
- Widget headerBuilder(
- BuildContext context
- List<
int> calendarDays = CupertinoDatePickerWidget.fullWeek, - double diameterRatio = 1.1,
- bool useSafeArea = false,
- Widget buttonBuilder(
- BottomPicker instance,
- BuildContext context
- @Deprecated('Use buttonBuilder instead') bool displaySubmitButton = true,
- @Deprecated('Use buttonBuilder instead') Widget? buttonContent,
- @Deprecated('Use buttonBuilder instead') BoxDecoration? buttonStyle,
- @Deprecated('Use buttonBuilder instead') MainAxisAlignment buttonAlignment = MainAxisAlignment.center,
- @Deprecated('Use buttonBuilder instead') Color? buttonSingleColor,
- @Deprecated('Use buttonBuilder instead') double? buttonPadding,
- @Deprecated('Use buttonBuilder instead') double? buttonWidth,
- TextStyle? pickerTextStyle,
Implementation
BottomPicker.time({
super.key,
required this.initialTime,
this.maxTime,
this.minTime,
this.dismissable = false,
this.onChange,
@Deprecated(
'Use buttonBuilder with a callback widget to handle the onSubmit action instead',
)
this.onSubmit,
@Deprecated(
'Use buttonBuilder with a callback widget to handle the onSubmit action instead',
)
this.closeOnSubmit = true,
this.onDismiss,
this.bottomPickerTheme = BottomPickerTheme.blue,
this.gradientColors,
this.minuteInterval = 1,
this.use24hFormat = false,
this.backgroundColor = Colors.white,
this.pickerThemeData,
this.layoutOrientation = TextDirection.ltr,
this.height,
this.showTimeSeparator = false,
this.itemExtent = 30,
this.headerBuilder,
this.calendarDays = CupertinoDatePickerWidget.fullWeek,
this.diameterRatio = 1.1,
this.useSafeArea = false,
this.buttonBuilder,
@Deprecated('Use buttonBuilder instead') this.displaySubmitButton = true,
@Deprecated('Use buttonBuilder instead') this.buttonContent,
@Deprecated('Use buttonBuilder instead') this.buttonStyle,
@Deprecated('Use buttonBuilder instead')
this.buttonAlignment = MainAxisAlignment.center,
@Deprecated('Use buttonBuilder instead') this.buttonSingleColor,
@Deprecated('Use buttonBuilder instead') this.buttonPadding,
@Deprecated('Use buttonBuilder instead') this.buttonWidth,
this.pickerTextStyle,
}) {
datePickerMode = CupertinoDatePickerMode.time;
bottomPickerType = BottomPickerType.time;
dateOrder = null;
onRangeDateSubmitPressed = null;
initialDateTime = null;
assertInitialValues();
}