buttonPadding property
the padding that will be applied to the button if the padding is null the button will be rendered null
Implementation
@Deprecated('Use buttonBuilder instead')
final double? buttonPadding;
the padding that will be applied to the button if the padding is null the button will be rendered null
@Deprecated('Use buttonBuilder instead')
final double? buttonPadding;