buttonWidth property
the width that will be applied to the button if the buttonWidth is null the button will be rendered with null
Implementation
@Deprecated('Use buttonBuilder instead')
final double? buttonWidth;
the width that will be applied to the button if the buttonWidth is null the button will be rendered with null
@Deprecated('Use buttonBuilder instead')
final double? buttonWidth;