minuteInterval property
The interval of the minutes in the time picker. By default minuteInterval is set to 1, which means that the user can select any minute value from 0 to 59.
if minuteInterval is outside the range of 1 to 59 an assertion error will be thrown.
Implementation
final int minuteInterval;