pickerThemeData property

CupertinoTextThemeData? pickerThemeData
final

The theme data to be used for the picker. When pickerThemeData is null, the default theme data of the CupertinoTimerPicker will be used.

Implementation

final CupertinoTextThemeData? pickerThemeData;