textStyle property
The text style to be used for the items in the picker. When the textstyle is null the default text style of the CupertinoTimerPicker will be used.
Implementation
final TextStyle? textStyle;
The text style to be used for the items in the picker. When the textstyle is null the default text style of the CupertinoTimerPicker will be used.
final TextStyle? textStyle;